import { useEffect, useRef, useState } from "react";
import "./index.less";

interface IProps {
  className: string;
  data: any;
}

function TimeScroll(props: IProps) {
  const [cursorStatic, setCursorStatic] = useState({
    top: 0,
    color: "var(--color-fill-4)",
  });
  const [cursorActive, setCursorActive] = useState({
    top: 0,
    color: "var(--color-border-3)",
  });
  const [intervalPixel, setIntervalPixel] = useState<number>();
  const cursorActiveRef = useRef<HTMLDivElement | null>(null);
  const cursorStaticRef = useRef<HTMLDivElement | null>(null);
  const orbitRef = useRef<HTMLDivElement | null>(null);

  /**
   * 点击打圈圈 cursorStatic
   */
  const onMouseDown = (ev: any) => {
    const orbitClient = orbitRef.current!.getBoundingClientRect();
    let mouseY = (ev || window.event).clientY; //鼠标按下的位置
    if (mouseY > orbitClient.top && mouseY < orbitClient.bottom)
      setCursorStatic((p) => ({ ...p, top: mouseY - orbitClient.top - 4 }));
  };

  /**
   * 移动圈圈 coursorActive
   */
  const onMouseMove = (ev: any) => {
    const orbitClient = orbitRef.current!.getBoundingClientRect();
    const mouseY = (ev || window.event).clientY;
    if (mouseY > orbitClient.top && mouseY < orbitClient.bottom)
      setCursorActive((p) => ({ ...p, top: mouseY - orbitClient.top - 4 }));
  };

  useEffect(() => {
    if (props.data) {
      const years = [...new Set(props.data.map((i: any) => i.year))];
      const avg = orbitRef.current!.clientHeight / years.length;
      setIntervalPixel(avg);
    }
  }, [props.data, orbitRef.current]);

  return (
    <div
      className={`timescroll ${props.className}`}
      onMouseMove={onMouseMove}
      onMouseDown={onMouseDown}
    >
      <svg
        className="caret up"
        xmlns="http://www.w3.org/2000/svg"
        viewBox="0 0 32 32"
      >
        <path d="M8 20l8-10l8 10z" fill="currentColor"></path>
      </svg>
      <div className="orbit" ref={orbitRef}>
        <span
          ref={cursorStaticRef}
          className="cursor static"
          style={{ ...cursorStatic }}
        ></span>
        <span
          ref={cursorActiveRef}
          className="cursor active"
          style={{ ...cursorActive }}
        ></span>
        {props.data.map((item: any, index: number) => {
          return item.data.length > 0 ? (
            <div
              key={index}
              className="node bingo"
              style={{ top: intervalPixel * index + "px" }}
              data-year={item.year}
            ></div>
          ) : (
            <div
              key={index}
              className="node empty"
              style={{ top: intervalPixel * index + "px" }}
            ></div>
          );
        })}
      </div>
      <svg
        className="caret down"
        xmlns="http://www.w3.org/2000/svg"
        viewBox="0 0 32 32"
      >
        <path d="M24 12l-8 10l-8-10z" fill="currentColor"></path>
      </svg>
    </div>
  );
}

export default TimeScroll;
